@@ -1,14 +1,11 @@
-from lbworkflow.flowgen import FlowAppGenerator
-from lbworkflow.flowgen import clean_generated_files
+from lbworkflow.flowgen import FlowAppGenerator, clean_generated_files
 from lbworkflow.tests.issue.models import Issue
-from lbworkflow.tests.purchase.models import Item
-from lbworkflow.tests.purchase.models import Purchase
+from lbworkflow.tests.purchase.models import Item, Purchase
 
 from .test_base import BaseTests
 
 
 class ViewTests(BaseTests):
-
     def test_gen_no_item_list(self):
         FlowAppGenerator().gen(Issue)
         clean_generated_files(Issue)
